# 170823 - based on denoise_v5.R

setwd("~/Documents/UNI_und_VORLESUNGEN/11 phd projects/1 Meta HAPLOTYPING/2 JAMP DceM/R_dif_ee_filtering")

library("seqinr")



# MAKE PLOT SCRIPT

file <- "1_tables/DceM__ee0.02_noDenoise.csv"


my_plot <- function(file=NA, names=F){

data <- read.csv(file, stringsAsFactors=F)

print(head(data, 30))

lm <- lm(log10(data$mean[data$color=="Black"]) ~log10(data$mg[data$color=="Black"]))
summary <- summary(lm)
print(summary)


pdf(sub(".csv", ".pdf", file), height=6, width=4, useDingbats=F)
plot(0.0001, log="xy", ylim=c(0.003, 100), xaxt="n", yaxt="n", ylab="relative abundance", xlab="specimen weight in mg", xlim=c(0.1, 500))



# get point types!

if(!is.null(data$sd)){
i <- 1
for(i in 1:nrow(data)){
lines(c(data$mg[i], data$mg[i]), c(data$mean[i]-data$sd[i], data$mean[i]+data$sd[i]), col=data$color[i])
}

type <- rep(1, 1, nrow(data))
type[is.na(data$A)] <- "B"
type[is.na(data$B)] <- "A"

data$color[is.na(data$A)] <- "deepskyblue"
data$color[is.na(data$B)] <- "blue"



points(data$mg[!is.na(data$sd)], data$mean[!is.na(data$sd)], col=data$color[!is.na(data$sd)], pch=1)

points(data$mg[is.na(data$sd)], data$mean[is.na(data$sd)], col= data$color[is.na(data$sd)], pch=type[is.na(data$sd)], cex=0.8)
abline(lm, col="red")
} else { # without replicates (pooled)
points(data$mg, data$mean, col=data$color, pch=1)
abline(lm, col="red")
}


axis(2, at=c(0.003, 0.01, 0.1, 1, 10, 100), labels=c("0.003", "0.01", "0.1", "1", "10", "100"), las=1)
axis(1, at=c(0.1, 1, 10, 100), labels=c(0.1, 1, 10, 100), las=1)

if(names){
text(data$mg[data$color=="Black"], data$mean[data$color=="Black"]*1.2, data$mgorig[data $color=="Black"], col="Darkgreen", cex=0.5)
}
p <- round(summary$coefficients[,4][2], 4)
if (p < 0.001){p <- "< 0.001"} else {p <- paste("","=",round(p, 3))}
text <- paste(sum(data$color=="Black"), " + ", sum(data$color=="Gray"), " + ", sum(data$color=="blue"), " + ", sum(data$color=="deepskyblue"), "\nR2 = ", round(unlist(summary[9]), 3), "\np ", p, sep="")
text(0.09, 120, text, adj=c(0,1))

dev.off()
message("plot_done!")
}

#my_plot("1_tables/170721_DceM_NoFiler.csv")
#my_plot("1_tables/170721_DceM_unoise3.csv")



vars <- c("", "_ee2", "_ee1", "_ee0.5", "_ee0.2", "_ee0.1", "_ee0.05", "_ee0.02")

g <- 8

for (g in 1:8){

# MAKE PLOT WITHOUT FILTERING



system2("usearch", paste("-fastx_uniques _data/09_DceM_fwhF1B_fwhR12_PE_cut_minmax", vars[g], "_N1000000.fasta -fastaout 1_imputfiles/09_DceM_fwhF1B_fwhR12_PE_cut_minmax", vars[g], "_N1000000+single.txt -sizeout -relabel Uniq", sep=""))

system2("usearch", paste("-fastx_uniques _data/10_DceM_fwhF13_fwhR13_PE_cut_minmax", vars[g], "_N1000000.fasta -fastaout 1_imputfiles/10_DceM_fwhF13_fwhR13_PE_cut_minmax", vars[g], "_N1000000+single.txt -sizeout -relabel Uniq", sep=""))


# check and rename sequence names (to have the same names!)

sequA <- read.fasta(paste("1_imputfiles/09_DceM_fwhF1B_fwhR12_PE_cut_minmax", vars[g], "_N1000000+single.txt", sep=""), forceDNAtolower=F, as.string=T)
sequB <- read.fasta(paste("1_imputfiles/10_DceM_fwhF13_fwhR13_PE_cut_minmax", vars[g], "_N1000000+single.txt", sep=""), forceDNAtolower=F, as.string=T)


tabA <- data.frame("sequ"=as.vector(unlist(sequA)), "abundA"=names(sequA), stringsAsFactors=F)
tabB <- data.frame("sequ"=as.vector(unlist(sequB)), "abundB"=names(sequB), stringsAsFactors=F)

tab <- merge(tabA, tabB, by="sequ", all=T, sort=F)

tab <- data.frame("sequ"=tab[,-c(2,3)], "ID"=1:nrow(tab), "abundA"=as.numeric(sub(".*;size=(.*);", "\\1", tab$abundA)), "abundB"=as.numeric(sub(".*;size=(.*);", "\\1", tab$abundB)), "isA"=c(!is.na(tab$abundA))*1, "isB"=c(!is.na(tab$abundB))*1, "both"=c(!is.na(tab$abundA))*1+c(!is.na(tab$abundB))*1,  stringsAsFactors=F)

head(tab)

new_names <- tab$both

new_names[tab$isA==1] <- "OnlyA_"
new_names[tab$isB==1] <- "OnlyB_"
new_names[tab$both==2] <- "Both_"

table(new_names)


# write fsta files -> same sequences = same name!
namesA <- paste(new_names[tab$isA==1], tab$ID[tab$isA==1], ";size=", tab$abundA[tab$isA==1], ";", sep="")
write.fasta(as.list(tab$sequ[tab$isA==1]), namesA, paste("1_imputfiles/09_DceM_fwhF1B_fwhR12_PE_cut_minmax", vars[g], "_N1000000+single_renamed.txt", sep=""))

namesB <- paste(new_names[tab$isB==1], tab$ID[tab$isB==1], ";size=", tab$abundB[tab$isB==1], ";", sep="")
write.fasta(as.list(tab$sequ[tab$isB==1]), namesB, paste("1_imputfiles/10_DceM_fwhF13_fwhR13_PE_cut_minmax", vars[g], "_N1000000+single_renamed.txt", sep=""))


# replicate A
system2("vsearch", paste("-usearch_global 1_imputfiles/09_DceM_fwhF1B_fwhR12_PE_cut_minmax", vars[g], "_N1000000+single_renamed.txt -db 161226_fwh1_DceM.txt -blast6out 1_matches/09_DceM_", vars[g], ".txt -strand plus -id 0.97", sep=""))
# replicate B
system2("vsearch", paste("-usearch_global 1_imputfiles/10_DceM_fwhF13_fwhR13_PE_cut_minmax", vars[g], "_N1000000+single_renamed.txt -db 161226_fwh1_DceM.txt -blast6out 1_matches/10_DceM_", vars[g], ".txt -strand plus -id 0.97", sep=""))


# vsearch "usearch_global"
tab_A <- read.csv(paste("1_matches/09_DceM_", vars[g], ".txt", sep=""), sep="\t", stringsAsFactors=F, header=F)
tab_A <- data.frame(tab_A, "abund_A"=as.numeric(sub(".*size=(.*);", "\\1", tab_A$V1))/1000000*100, "mg_A"=as.numeric(sub(".*_(.*)", "\\1", tab_A$V2)))

tab_A <- data.frame(tab_A, color="Gray", stringsAsFactors=F)
head(tab_A, 100)
tab_A$color[tab_A$V3==100 & tab_A$V4==178 & tab_A$V7==1 & tab_A$V8==178] <- "Black"

tab_A <- tab_A[,c(1, 2, 13, 14, 15)]
tab_A <- cbind(tab_A, "ID"=sub("(.*);size=.*", "\\1", tab_A$V1))


tab_B <- read.csv(paste("1_matches/10_DceM_", vars[g], ".txt", sep=""), sep="\t", stringsAsFactors=F, header=F)
tab_B <- data.frame(tab_B, "abund_B"=as.numeric(sub(".*size=(.*);", "\\1", tab_B$V1))/1000000*100, "mg_B"=as.numeric(sub(".*_(.*)", "\\1", tab_B$V2)))

tab_B <- data.frame(tab_B, color="Gray", stringsAsFactors=F)
head(tab_B, 100)
tab_B$color[tab_B$V3==100 & tab_B$V4==178 &  tab_B$V7==1 & tab_B$V8==178] <- "Black"

tab_B <- tab_B[,c(1, 2, 13, 14, 15)]
tab_B <- cbind(tab_B, "ID"=sub("(.*);size=.*", "\\1", tab_B$V1))



tab_all <- merge(tab_A, tab_B, by="ID", all=T, sort=F)
tab_all <- tab_all[,c(1, 2, 7, 3, 6, 4, 9, 10, 11)]


# remove reads only in one sample
#tab_all$A[tab_all$abund_A<0.003] <-NA
tab_all$abund_A[tab_all$abund_A<0.003] <-NA

#tab_all$B[tab_all$abund_B<0.003] <-NA
tab_all$abund_B[tab_all$abund_B<0.003] <-NA



tab_all <- cbind(tab_all, mean=rowMeans(tab_all[,c(6,7)]) )

tab_all$mean[is.na(tab_all$abund_B)] <- tab_all$abund_A[is.na(tab_all$abund_B)]

tab_all$mean[is.na(tab_all$abund_A)] <- tab_all$abund_B[is.na(tab_all$abund_A)]

head(tab_all)
sum(tab_all$mean)

tab_all <- tab_all[tab_all$mean>=0.003,]

names(tab_all)[c(2,3,4,5,8)] <- c("A", "B", "mgorig", "color", "mg")
tab_all$color[is.na(tab_all$color)] <- tab_all$color.y[is.na(tab_all$color)]
tab_all <- tab_all[,-9]


# remove reads only in one sample
tab_all$A[is.na(tab_all$abund_A)] <-NA

tab_all$B[is.na(tab_all$abund_B)] <-NA
#tab_all$abund_B[tab_all$abund_B<0.003] <-NA


tab_all <- tab_all[!is.na(tab_all$mean),]

# calculate SD
sd <- NULL
for(i in 1:nrow(tab_all)){
sd[i] <- sd(c(tab_all$abund_A[i], tab_all$abund_B[i]))
}
tab_all <- cbind(tab_all, sd)

head(tab_all, 30)
nrow(tab_all)

sum(tab_all$mean[tab_all$color=="Gray"])

# haplo detected
sum(tab_all$color=="Black")

# noise 
sum(tab_all$color=="Gray")

table(sub("(.*)_.*", "\\1", tab_all$A))
table(sub("(.*)_.*", "\\1", tab_all$B))


tab_all <- tab_all[order(tab_all$mean, decreasing=T),]


# write table!
write.csv(tab_all, file=paste("1_tables/", g, "_DceM_", vars[g], "_noDenoise.csv", sep=""), row.names=F)

#make plot!
my_plot(paste("1_tables/", g, "_DceM_", vars[g], "_noDenoise.csv", sep=""))

}





